/*
 * Copyright (c) 2005 TopCoder, Inc., All Rights Reserved
 */
package com.topcoder.network.synchronization.protocol;

import com.topcoder.network.synchronization.bean.PeerGroupInfo;

/**
 * Receive messages from the peer group using UDP protocol. 
 * 
 * @author TCSDESIGNER
 * @version 1.0
 */
public interface MessageReceiver extends Runnable{
    
    /**
     * 
     * Set the PeerGroupInfo of this receiver.
     * the PeerGroupInfo is used to tell the receiver where the message should be received.
     * 
     * @param groupInfo the PeerGroupInfo of this receiver  
     * 
     */
    void setPeerGroupInfo(PeerGroupInfo groupInfo);
    
    /**
     * Return the PeerGroupInfo of this receiver.
     * @return the PeerGroupInfo of this receiver.
     */
    PeerGroupInfo getPeerGroupInfo();   
           
    /**
     * Stop this receiver.
     *
     */
    void stop();    
       
    /**
     * Add a listener to this receiver.
     * The added listener will be added to this listener chain in this receiver.
     * When a message received, the listeners will be called one by one to deal this messages.   
     * 
     * @param listener the listener to add
     */
    void addMessageListener(MessageListener listener);
        
    /**
     * Remove the listener of this receiver.
     * 
     * @param listener the listener to remove  
     */
    void removeMessageListener(MessageListener listener);
    
    /**
     * Return ths first MessageListener of this receiver.
     *  
     * @return ths first MessageListener of this receiver
     */
    MessageListener getMessageListener();
    
    /**
     * Remove all message listeners from this receiver. 
     *
     */
    void clearMessageListeners();
}
